finds the rss/atom feed in a given url

Usage:
======

$ python -m feedfinder.__init__ https://www.bbc.co.uk/sport/football
http://feeds.bbci.co.uk/sport/football/rss.xml

```
>>> import feedfinder
>>> feedfinder.feed('https://bbc.co.uk/sport/football')
http://feeds.bbci.co.uk/sport/football/rss.xml
```

